@@ -1879,9 +1879,9 @@ powvalue(VALUE *v1, VALUE *v2, VALUE *vres)
 					*vres = error_value(E_1OVER0);
 					break;
 				}
-				/* 0 ^ non-neg is zero, including 0^0 */
+				/* 0 ^ non-neg is 1, including 0^0 */
 				vres->v_type = V_NUM;
-				vres->v_num = qlink(&_qzero_);
+				vres->v_num = qlink(&_qone_);
 			} else if (qisint(real_v2)) {
 				vres->v_num = qpowi(v1->v_num, real_v2);
 			} else {
